var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { DynamoDBClient, UpdateItemCommand, } from '@aws-sdk/client-dynamodb';
import { marshall } from '@aws-sdk/util-dynamodb';
export function updateItem({ accessKey, secretKey, region, tableName, keys, item }) {
    return __awaiter(this, void 0, void 0, function* () {
        const client = new DynamoDBClient({
            region,
            credentials: {
                accessKeyId: accessKey,
                secretAccessKey: secretKey,
            },
        });
        Object.keys(keys).forEach((key) => {
            delete item[key];
        });
        const attributeNames = Object.keys(item);
        const updateExpression = `SET ${attributeNames.map((_k, index) => `#setAttr${index} = :setAttr${index}`).join(', ')}`;
        const expressionAttNames = attributeNames.reduce((accumulator, k, index) => (Object.assign(Object.assign({}, accumulator), { [`#setAttr${index}`]: k })), {});
        const expressionAttValues = attributeNames.reduce((accumulator, k, index) => (Object.assign(Object.assign({}, accumulator), { [`:setAttr${index}`]: item[k] })), {});
        const params = {
            TableName: tableName,
            Key: marshall(keys),
            UpdateExpression: updateExpression,
            ExpressionAttributeNames: expressionAttNames,
            ExpressionAttributeValues: expressionAttValues,
            ReturnValues: 'ALL_NEW',
        };
        try {
            const data = yield client.send(new UpdateItemCommand(params));
            return data.$metadata.httpStatusCode === 200;
        }
        catch (error) {
            console.log(error);
            return false;
        }
    });
}
//# sourceMappingURL=updateItem.js.map