var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { S3Client, GetObjectCommand } from '@aws-sdk/client-s3';
function streamToString(stream) {
    return __awaiter(this, void 0, void 0, function* () {
        const reader = stream.getReader();
        let done = false;
        const decoder = new TextDecoder();
        let string = '';
        do {
            const result = yield reader.read();
            done = result.done;
            if (result.value) {
                string += decoder.decode(result.value, { stream: true });
            }
        } while (!done);
        return string;
    });
}
/**
 * Reads a json file from S3
 */
export function getObject({ accessKey, secretKey, region, bucketName, objectKey, }) {
    return __awaiter(this, void 0, void 0, function* () {
        const cfnClient = new S3Client({
            region,
            credentials: {
                accessKeyId: accessKey,
                secretAccessKey: secretKey,
            },
        });
        const params = {
            Bucket: bucketName,
            Key: objectKey,
            ResponseContentType: 'application/json',
        };
        const data = yield cfnClient.send(new GetObjectCommand(params));
        if (!data.Body)
            return {};
        try {
            const jsonStr = yield streamToString(data.Body);
            return JSON.parse(jsonStr);
        }
        catch (error) {
            throw new Error(`Couldn't get or parse the json file at "${objectKey}". Error ${error}`);
        }
    });
}
//# sourceMappingURL=getObject.js.map