var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { SFNClient, ListExecutionsCommand, } from '@aws-sdk/client-sfn';
/**
 * Get the latest execution of the provided step functions state machine
 */
export function listExecutions({ accessKey, secretKey, region, stateMachineArn, }) {
    var _a;
    return __awaiter(this, void 0, void 0, function* () {
        const cfnClient = new SFNClient({
            region,
            credentials: {
                accessKeyId: accessKey,
                secretAccessKey: secretKey,
            },
        });
        const params = { stateMachineArn, maxResults: 1 };
        let data;
        do {
            // This command returns the latest execution first
            // see https://docs.aws.amazon.com/AWSJavaScriptSDK/v3/latest/clients/client-sfn/classes/listexecutionscommand.html
            data = yield cfnClient.send(new ListExecutionsCommand(params));
            params.nextToken = data.nextToken;
            if (data.executions && ((_a = data.executions) === null || _a === void 0 ? void 0 : _a.length) > 0) {
                return data.executions[0];
            }
        } while (params.nextToken);
        return undefined;
    });
}
//# sourceMappingURL=listExecutions.js.map